Package: RNeXML
Type: Package
Title: Semantically Rich I/O for the 'NeXML' Format
Version: 2.4.11
Authors@R: c(person("Carl", "Boettiger", role = c("cre", "aut"),
    email="cboettig@gmail.com", comment = c(ORCID="0000-0002-1642-628X")), 
    person("Scott", "Chamberlain", role ="aut", comment = c(ORCID="0000-0003-1444-9135")), 
    person("Hilmar", "Lapp", role = "aut", comment = c(ORCID="0000-0001-9107-0714")), 
    person("Kseniia","Shumelchyk", role = "aut"), 
    person("Rutger", "Vos", role = "aut", comment = c(ORCID="0000-0001-9254-7318")))
Description: Provides access to phyloinformatic data in 'NeXML' format.  The
    package should add new functionality to R such as the possibility to
    manipulate 'NeXML' objects in more various and refined way and compatibility
    with 'ape' objects.
URL: https://docs.ropensci.org/RNeXML/,
        https://github.com/ropensci/RNeXML
BugReports: https://github.com/ropensci/RNeXML/issues
License: BSD_3_clause + file LICENSE
VignetteBuilder: knitr
Suggests: spelling, rdflib, geiger (>= 2.0), phytools (>= 0.3.93),
        knitr (>= 1.5), rfigshare (>= 0.3.0), knitcitations (>= 1.0.1),
        testthat (>= 0.10.0), rmarkdown (>= 0.3.3), xslt, covr,
        taxalight, progress
Depends: R (>= 3.0.0), ape (>= 3.1), methods (>= 3.0.0)
Imports: XML (>= 3.95), plyr (>= 1.8), reshape2 (>= 1.2.2), httr (>=
        0.3), uuid (>= 0.1-1), dplyr (>= 0.7.0), tidyr (>= 0.3.1),
        stringr (>= 1.0), stringi, xml2, rlang
Collate: 'S4-utils.R' 'classes.R' 'add_basic_meta.R' 'add_characters.R'
        'add_meta.R' 'add_namespaces.R' 'nexmlTree.R' 'add_trees.R'
        'character_classes.R' 'concatenate_nexml.R' 'constructors.R'
        'deprecated.R' 'get_basic_metadata.R' 'get_characters.R'
        'get_level.R' 'get_metadata.R' 'get_namespaces.R' 'get_rdf.R'
        'get_taxa.R' 'get_taxa_meta.R' 'get_trees.R'
        'internal_get_node_maps.R' 'internal_isEmpty.R'
        'internal_name_by_id.R' 'internal_nexml_id.R' 'meta.R'
        'nexml_add.R' 'nexml_get.R' 'nexml_methods.R' 'nexml_publish.R'
        'nexml_read.R' 'nexml_validate.R' 'nexml_write.R'
        'prefixed-uris.R' 'simmap.R' 'taxize_nexml.R' 'tbl_df.R'
        'utils.R'
RoxygenNote: 7.2.3
X-schema.org-applicationCategory: Data Publication
X-schema.org-keywords: metadata, nexml, phylogenetics, linked-data
X-schema.org-isPartOf: https://ropensci.org
Language: en-US
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2023-02-01 16:56:11 UTC; cboettig
Author: Carl Boettiger [cre, aut] (<https://orcid.org/0000-0002-1642-628X>),
  Scott Chamberlain [aut] (<https://orcid.org/0000-0003-1444-9135>),
  Hilmar Lapp [aut] (<https://orcid.org/0000-0001-9107-0714>),
  Kseniia Shumelchyk [aut],
  Rutger Vos [aut] (<https://orcid.org/0000-0001-9254-7318>)
Maintainer: Carl Boettiger <cboettig@gmail.com>
Repository: CRAN
Date/Publication: 2023-02-01 17:50:07 UTC
Built: R 4.6.0; ; 2026-04-29 09:52:42 UTC; unix
