# Generated by roxygen2: do not edit by hand

S3method(nexml_read,XMLInternalDocument)
S3method(nexml_read,XMLInternalNode)
S3method(nexml_read,character)
export(add_basic_meta)
export(add_characters)
export(add_meta)
export(add_namespaces)
export(add_trees)
export(expand_prefix)
export(flatten_multiphylo)
export(get_all_meta)
export(get_characters)
export(get_characters_list)
export(get_citation)
export(get_flat_trees)
export(get_level)
export(get_license)
export(get_meta)
export(get_metadata)
export(get_metadata_values)
export(get_namespaces)
export(get_otu)
export(get_otus_list)
export(get_rdf)
export(get_taxa)
export(get_taxa_list)
export(get_trees)
export(get_trees_list)
export(meta)
export(nexml)
export(nexml.cell)
export(nexml.char)
export(nexml.characters)
export(nexml.edge)
export(nexml.format)
export(nexml.matrix)
export(nexml.member)
export(nexml.node)
export(nexml.otu)
export(nexml.otus)
export(nexml.polymorphic_states)
export(nexml.row)
export(nexml.seq)
export(nexml.state)
export(nexml.states)
export(nexml.tree)
export(nexml.trees)
export(nexml.uncertain_state)
export(nexml.uncertain_states)
export(nexml_add)
export(nexml_figshare)
export(nexml_get)
export(nexml_publish)
export(nexml_read)
export(nexml_to_simmap)
export(nexml_validate)
export(nexml_write)
export(read.nexml)
export(reset_id_counter)
export(simmap_to_nexml)
export(taxize_nexml)
export(write.nexml)
exportClasses(nexml)
exportMethods("slot<-")
exportMethods(slot)
exportMethods(summary)
import(XML)
import(ape)
import(httr)
import(methods)
import(reshape2)
import(uuid)
importClassesFrom(methods,MethodWithNext)
importFrom(dplyr,"%>%")
importFrom(dplyr,any_of)
importFrom(dplyr,bind_rows)
importFrom(dplyr,coalesce)
importFrom(dplyr,left_join)
importFrom(dplyr,matches)
importFrom(dplyr,mutate)
importFrom(dplyr,mutate_at)
importFrom(dplyr,rename)
importFrom(dplyr,select)
importFrom(methods,addNextMethod)
importFrom(methods,cacheMethod)
importFrom(methods,className)
importFrom(methods,getClassDef)
importFrom(methods,getGeneric)
importFrom(methods,new)
importFrom(methods,packageSlot)
importFrom(methods,selectMethod)
importFrom(plyr,arrange)
importFrom(plyr,compact)
importFrom(rlang,":=")
importFrom(stats,na.omit)
importFrom(stats,setNames)
importFrom(stringi,stri_match_first_regex)
importFrom(stringi,stri_replace_first_regex)
importFrom(stringr,str_replace)
importFrom(tidyr,spread)
importFrom(utils,capture.output)
importFrom(utils,head)
importFrom(utils,object.size)
importFrom(utils,packageName)
importFrom(uuid,UUIDgenerate)
importFrom(xml2,read_xml)
