% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/get_basic_metadata.R
\name{get_license}
\alias{get_license}
\title{get_license}
\usage{
get_license(nexml)
}
\arguments{
\item{nexml}{a nexml object}
}
\value{
the list of taxa
}
\description{
get_license
}

