% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/internal_nexml_id.R
\name{reset_id_counter}
\alias{reset_id_counter}
\title{reset id counter}
\usage{
reset_id_counter()
}
\description{
reset the id counter
}
